"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterWithCustomTargeting = void 0;
function filterWithCustomTargeting(userAttributes, query, startDate, endDate) {
    var item = {
        query: query,
        startDate: startDate,
        endDate: endDate,
    };
    var now = (userAttributes.date && new Date(userAttributes.date)) || new Date();
    if (item.startDate && new Date(item.startDate) > now) {
        return false;
    }
    else if (item.endDate && new Date(item.endDate) < now) {
        return false;
    }
    if (!item.query || !item.query.length) {
        return true;
    }
    return item.query.every(function (filter) {
        return objectMatchesQuery(userAttributes, filter);
    });
}
exports.filterWithCustomTargeting = filterWithCustomTargeting;
function isString(val) {
    return typeof val === 'string';
}
function isNumber(val) {
    return typeof val === 'number';
}
function objectMatchesQuery(userattr, query) {
    var result = (function () {
        var property = query.property;
        var operator = query.operator;
        var testValue = query.value;
        if (query &&
            query.property === 'urlPath' &&
            query.value &&
            typeof query.value === 'string' &&
            query.value !== '/' &&
            query.value.endsWith('/')) {
            testValue = query.value.slice(0, -1);
        }
        // Check is query property is present in userAttributes. Proceed only if it is present.
        if (!(property && operator)) {
            return true;
        }
        if (Array.isArray(testValue)) {
            if (operator === 'isNot') {
                return testValue.every(function (val) {
                    return objectMatchesQuery(userattr, { property: property, operator: operator, value: val });
                });
            }
            return !!testValue.find(function (val) {
                return objectMatchesQuery(userattr, { property: property, operator: operator, value: val });
            });
        }
        var value = userattr[property];
        if (Array.isArray(value)) {
            return value.includes(testValue);
        }
        switch (operator) {
            case 'is':
                return value === testValue;
            case 'isNot':
                return value !== testValue;
            case 'contains':
                return (isString(value) || Array.isArray(value)) && value.includes(String(testValue));
            case 'startsWith':
                return isString(value) && value.startsWith(String(testValue));
            case 'endsWith':
                return isString(value) && value.endsWith(String(testValue));
            case 'greaterThan':
                return isNumber(value) && isNumber(testValue) && value > testValue;
            case 'lessThan':
                return isNumber(value) && isNumber(testValue) && value < testValue;
            case 'greaterThanOrEqualTo':
                return isNumber(value) && isNumber(testValue) && value >= testValue;
            case 'lessThanOrEqualTo':
                return isNumber(value) && isNumber(testValue) && value <= testValue;
        }
        return false;
    })();
    return result;
}
//# sourceMappingURL=filter-with-custom-targeting.js.map